@@ -10,6 +10,9 @@
 int			prepare_exec(char *);
 void			do_exec(struct action_tokens *);
 void			do_pipe_line(struct action_tokens *);
+void			do_echo(struct action_tokens *);
+void			do_syslog(struct action_tokens *);
+int			parse_syslog_faclevel(char *, int *, int *);
 
 void			free_tokens(struct action_tokens *);
 struct action_tokens	*collect_tokens(char *);
@@ -23,6 +26,9 @@ void			flush_queue();
 int			prepare_exec();
 void			do_exec();
 void			do_pipe_line();
+void			do_echo();
+void			do_syslog();
+int			parse_syslog_faclevel();
 
 void			free_tokens();
 struct action_tokens	*collect_tokens();
